@@ -1,4 +1,4 @@
-/*	$OpenBSD: ntp_msg.c,v 1.14 2004/12/14 06:27:13 dtucker Exp $ */
+/*	$OpenBSD: ntp_msg.c,v 1.15 2005/09/24 00:32:03 dtucker Exp $ */
 
 /*
  * Copyright (c) 2003, 2004 Henning Brauer <henning@openbsd.org>
@@ -27,10 +27,11 @@
 #include "ntp.h"
 
 int
-ntp_getmsg(char *p, ssize_t len, struct ntp_msg *msg)
+ntp_getmsg(struct sockaddr *sa, char *p, ssize_t len, struct ntp_msg *msg)
 {
 	if (len != NTP_MSGSIZE_NOAUTH && len != NTP_MSGSIZE) {
-		log_warnx("malformed packet received");
+		log_warnx("malformed packet received from %s",
+		    log_sockaddr(sa));
 		return (-1);
 	}
 
@@ -63,7 +64,7 @@ ntp_sendmsg(int fd, struct sockaddr *sa, struct ntp_msg *msg, ssize_t len,
 {
 	char		 buf[NTP_MSGSIZE];
 	char		*p = buf;
-	socklen_t	sa_len;
+	socklen_t	salen;
 
 #define	copyout(p,f)	memcpy((p), &(f), sizeof(f)); p += sizeof(f)
 
@@ -86,11 +87,11 @@ ntp_sendmsg(int fd, struct sockaddr *sa, struct ntp_msg *msg, ssize_t len,
 	copyout(p, msg->xmttime.fractionl);
 
 	if (sa != NULL)
-		sa_len = SA_LEN(sa);
+		salen = SA_LEN(sa);
 	else
-		sa_len = 0;
+		salen = 0;
 
-	if (sendto(fd, &buf, len, 0, sa, sa_len) != len) {
+	if (sendto(fd, &buf, len, 0, sa, salen) != len) {
 		if (errno == ENOBUFS || errno == EHOSTUNREACH ||
 		    errno == ENETDOWN || errno == EHOSTDOWN) {
 			/* logging is futile */
