@@ -1,4 +1,4 @@
-/* $Id: fake-rfc2553.h,v 1.2 2004/10/14 12:07:10 dtucker Exp $ */
+/* $Id: fake-rfc2553.h,v 1.3 2006/01/19 13:00:01 dtucker Exp $ */
 
 /*
  * Copyright (C) 2000-2003 Damien Miller.  All rights reserved.
@@ -83,6 +83,10 @@ struct sockaddr_in6 {
 #define AF_INET6 AF_MAX
 #endif
 
+#ifndef HAVE_IN6ADDR_ANY
+extern const struct in6_addr in6addr_any;
+#endif
+
 /*
  * Next, RFC2553 name / address resolution API
  */
